@@ -17,5 +17,5 @@ class DefocusAnalyzeResult:
     snapshot_file_id: str
     reference_image_file_ids: list[str]
     comparison_stopped_on_index: int
-    least_freq_diff: float
+    least_freq_diff: float | None
     is_defocused: bool
